import 'dart:io';

import 'package:flutter/material.dart';

import '../clx_webview_flutter.dart';

abstract class CaptchaUtil {
  static Future<bool>? generateCaptcha(
      {required BuildContext context,
      required String uri,
      required Future<bool> Function(JavaScriptMessage message)
          onCaptchaGenerated}) async {
    final result = await Navigator.push(context, PageRouteBuilder(
      pageBuilder: (context, animation, secondaryAnimation) {
        final ScalloldWebViewViewModel customController =
            ScalloldWebViewViewModel.loadRequest(
                requestedUrl: Uri.parse(uri), title: '验证码');
        customController.setJavaScriptChannels(JavaScriptChannel(
          name: 'H5CallFlutterInterface',
          callback: (message) async {
            if (!context.mounted) {
              return CLXResult.fail(Exception('context not mounted'));
            }
            final result = await onCaptchaGenerated(message);
            if (result) {
              Navigator.pop(context, true);
              return CLXResult.fail(Exception('captcha failed'));
            } else if (Platform.isAndroid) {
              customController.controller.loadRequest(Uri.parse(uri));
              return CLXResult.succ(result);
            } else {
              customController.controller.reload();
              return CLXResult.succ(result);
            }
          },
        ));
        return ScaffoldWebView(customController: customController);
      },
    ));

    return Future.value(result == true);
  }
}
